tempotools
==========

.. automodule:: abjad.tools.tempotools

.. only:: html

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.tempotools.report_integer_tempo_rewrite_pairs.report_integer_tempo_rewrite_pairs
      ~abjad.tools.tempotools.rewrite_duration_under_new_tempo.rewrite_duration_under_new_tempo
      ~abjad.tools.tempotools.rewrite_integer_tempo.rewrite_integer_tempo
